@@ -15,7 +15,7 @@ from pyramid_mailer import get_mailer
 from pyramid_mailer.message import Message
 
 from por.models import Project, Group, DBSession, User, CustomerRequest
-from por.models.dashboard import ApplicationACL
+from por.models.dashboard import ApplicationACL, Contract
 from por.models.dashboard import Trac, Role, GoogleDoc, Estimation
 from por.dashboard.lib.widgets import SubmitButton, ResetButton, WizardForm
 from por.dashboard.fanstatic_resources import wizard as wizard_fanstatic
@@ -242,13 +242,45 @@ class CustomerRequests(colander.SequenceSchema):
     customer_request = CustomerRequest(title='')
 
 
+class CRperContracts(colander.MappingSchema):
+    class Contract(colander.Schema):
+          name = SchemaNode(typ=colander.String(),
+                             widget=TextInputWidget(placeholder=u'Contract name'),
+                             missing=colander.required,
+                             title=u'')
+          contract_number = SchemaNode(typ=colander.String(),
+                             widget=TextInputWidget(placeholder=u'Contract '
+                                                    'number'),
+                             missing=None,
+                             title=u'')
+          days = SchemaNode(typ=colander.Decimal(),
+                              widget=TextInputWidget(css_class='input-mini',
+                                                     placeholder=u'Days'),
+                              missing=None,
+                              title=u'')
+          ammount = SchemaNode(typ=colander.Decimal(),
+                              widget=TextInputWidget(css_class='input-mini',
+                                                     placeholder=u'Ammount in EUR'),
+                              missing=None,
+                              title=u'')
+          start_date = SchemaNode(typ=colander.Date(),
+                              missing=None,
+                              title=u'Start date')
+          end_date = SchemaNode(typ=colander.Date(),
+                              missing=None,
+                              title=u'End date')
+
+    customer_requests = CustomerRequests()
+    contract = Contract(name='',)
+
+
 class WizardSchema(colander.Schema):
     project = Definition()
     google_docs = GoogleDocsSchema()
     users = UsersSchema()
     new_users = NewUsersSchema()
     milestones = Milestones()
-    customer_requests = CustomerRequests()
+    contracts = CRperContracts()
 
 
 class Wizard(object):
@@ -286,30 +318,32 @@ class Wizard(object):
                 [(str(role.id), role.name) for role in roles]
 
         form['milestones'].widget = SequenceWidget(min_len=1)
-        form['customer_requests'].widget = SequenceWidget(min_len=2)
+        form['contracts'].title = ''
+        form['contracts']['customer_requests'].widget = SequenceWidget(min_len=2)
 
         controls = self.request.POST.items()
         if controls != []:
             try:
                 appstruct = form.validate(controls)
-                self.handle_save(appstruct)
+                self.handle_save(form, appstruct)
             except ValidationFailure as e:
                 result['form'] = e.render()
                 return result
 
-        appstruct = {'customer_requests': [{'ticket': True,
-                                            'title': u'Analisi'},
-                                           {'ticket': True,
-                                            'title': u'Supporto'}]
-                                       }
-
+        appstruct = {}
+        appstruct['contracts'] ={'customer_requests': []}
+        appstruct['contracts']['customer_requests'].append({'ticket': True,
+                                                            'title': u'Analisi'})
+        appstruct['contracts']['customer_requests'].append({'ticket': True,
+                                                            'title': u'Supporto'})
         result['form'] = form.render(appstruct=appstruct)
         return result
 
-    def handle_save(self, appstruct):
+    def handle_save(self, form, appstruct):
         """ The main handle method for the wizard. """
         customer = self.context.get_instance()
-        #create new users
+
+        # create new users
         recipients = []
         groups = {}
         mailer = get_mailer(self.request)
@@ -357,9 +391,15 @@ class Wizard(object):
             group = Group(roles=[role, ], users=users)
             project.add_group(group)
 
+        #create contract with cr
+        crs = appstruct['contracts']['customer_requests']
+        co =  appstruct['contracts']['contract']
+        contract = Contract(**co)
+        contract.project_id = project.id
+
         #create CR
         tickets = []
-        for cr in appstruct['customer_requests']:
+        for cr in crs:
             customer_request = CustomerRequest(name=cr['title'])
             person_types = {
                 'junior': 'Junior',
@@ -372,21 +412,23 @@ class Wizard(object):
             for key, value in person_types.items():
                 if cr[key]:
                     Estimation(person_type=value,
-                               days=cr[key],
-                               customer_request=customer_request)
+                            days=cr[key],
+                            customer_request=customer_request)
             project.add_customer_request(customer_request)
+            customer_request.contract = contract
             if not cr['ticket']:
                 continue
             tickets += [{'summary': cr['title'],
-                         'customerrequest': customer_request,
-                         'reporter': manager.email,
-                         'type': 'task',
-                         'priority': 'major',
-                         'milestone': 'Backlog',
-                         'owner': manager.email}]
+                        'customerrequest': customer_request,
+                        'reporter': manager.email,
+                        'type': 'task',
+                        'priority': 'major',
+                        'milestone': 'Backlog',
+                        'owner': manager.email}]
 
         #create project management CR and tickets
         project_management_cr = CustomerRequest(name="Project management")
+        project_management_cr.contract = contract
         project.add_customer_request(project_management_cr)
         project_management_tickets = PM_TICKETS
         for summary, description in project_management_tickets.items():
